import pathlib
import time
import os
import csv
import random
from rich.console import Console
from rich.markdown import Markdown

LEVEL = "LEVEL"
QUESTION = "QUESTION"
ANSWER = "ANSWER"


class Question(object):
    """
    class to hold the question data and methods
    TODO: needs to json methods for the REST API
    """
    def __init__(self, data):
        self._data = data
        self._clean_data()

    def _clean_data(self):
        """
        TODO needs quite bit of actual cleanup to make the parsing more robust
        """
        self._level = self._data[LEVEL].strip()
        self._question = self._data[QUESTION].strip()
        self._answers = self._data[ANSWER].strip().split(" ")

    def get_question(self):
        return self._question

    def get_possibilities(self):
        """returns a list of all the possible answers"""
        possibilities = []
        for key in self._data.keys():
            if key.isnumeric():
                possibilities.append(self._data[key])
        return possibilities

    def verify(self, answer):
        """needs quite some work"""
        if answer in self._data[ANSWER]:
            return True
        else:
            return False

    def get_right_answers(self):
        answers = []
        for answer in self._answers:
            if len(answer) == 0:
                print("question not complete...")
            else:
                answers.append(self._data[answer])
        return answers


class Database(object):
    """holds all the Question objects and methods to get new questions"""
    def __init__(self, filepath):
        self.filepath = filepath
        self._db = []
        self.setup()

    def setup(self):
        data = csv.DictReader(open(self.filepath, "r"))
        for row in data:
            self._db.append(Question(row))

    def get_question(self):
        return random.choice(self._db)


class Game(object):
    def __init__(self):
        self._stats = []

    def update_stats(self, stat):
        self._stats.append(stat)

    def get_stats(self):
        right = self._stats.count(True)
        wrong = self._stats.count(False)
        total = len(self._stats)
        return (right, wrong, total)


if __name__ == "__main__":
    pass

